@@ -9,7 +9,7 @@
 ## no critic (RequireUseStrict, RequireUseWarnings)
 package Riak::Light;
 {
-    $Riak::Light::VERSION = '0.11';
+    $Riak::Light::VERSION = '0.12';
 }
 ## use critic
 
@@ -31,12 +31,12 @@ use Moo;
 
 # ABSTRACT: Fast and lightweight Perl client for Riak
 
-has pid  => ( is => 'lazy', isa => Int, clearer  => 1 );
-has port => ( is => 'ro',   isa => Int, required => 1 );
-has host => ( is => 'ro',   isa => Str, required => 1 );
-has r    => ( is => 'ro',   isa => Int, default  => sub {2} );
-has w    => ( is => 'ro',   isa => Int, default  => sub {2} );
-has dw   => ( is => 'ro',   isa => Int, default  => sub {2} );
+has pid => ( is => 'lazy', isa => Int, clearer => 1, predicate => 1 );
+has port => ( is => 'ro', isa => Int, required => 1 );
+has host => ( is => 'ro', isa => Str, required => 1 );
+has r    => ( is => 'ro', isa => Int, default  => sub {2} );
+has w    => ( is => 'ro', isa => Int, default  => sub {2} );
+has dw   => ( is => 'ro', isa => Int, default  => sub {2} );
 
 has pr => ( is => 'ro', isa => Int, predicate => 1 );
 has pw => ( is => 'ro', isa => Int, predicate => 1 );
@@ -95,6 +95,8 @@ sub _build_driver {
 sub _build_socket {
     my ($self) = @_;
 
+    $self->pid;    # force associate the pid with the current socket
+
     my $host = $self->host;
     my $port = $self->port;
 
@@ -731,7 +733,7 @@ Riak::Light - Fast and lightweight Perl client for Riak
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
